@@ -7,7 +7,7 @@ License : GNU GPL version 3
 '''
 import sys
 
-from PyQt6 import QtGui, QtCore, QtWidgets
+from PyQt5 import QtGui, QtCore, QtWidgets
 
 import time, math, os.path, struct
 import utils
@@ -33,7 +33,7 @@ except:
 
 from pyqtgraph.exporters import Exporter
 from pyqtgraph.parametertree import Parameter
-from pyqtgraph.Qt import QtGui, QtCore, QtSvg, USE_PYSIDE
+from pyqtgraph.Qt import QtGui, QtCore, QtSvg
 from pyqtgraph import functions as fn
 import pyqtgraph as pg
 
@@ -85,12 +85,8 @@ class PQG_ImageExporter(Exporter):
 
     def export(self, fileName=None, toBytes=False, copy=False):
         if fileName is None and not toBytes and not copy:
-            if USE_PYSIDE:
-                filter = ["*."+str(f)
-                          for f in QtGui.QImageWriter.supportedImageFormats()]
-            else:
-                filter = ["*."+bytes(f).decode('utf-8')
-                          for f in QtGui.QImageWriter.supportedImageFormats()]
+            filter = ["*."+bytes(f).decode('utf-8')
+                      for f in QtGui.QImageWriter.supportedImageFormats()]
             preferred = ['*.png', '*.tif', '*.jpg']
             for p in preferred[::-1]:
                 if p in filter:
